/**
 * @description 公共请求方法
 */
import axios from "axios";
/**
 * @description 检查业务错误码
 * @param response
 */
export function checkCode(response) {
	const { data } = response;
	if (data && data.code !== 0) {
		const e = new Error(data.msg);
		e.code = data.code;
		e.msg = data.msg;
		throw e;
	}
	return response.data;
}

export function disposeError(error) {
	const { code, msg } = error;
	if (msg) {
		//TODO: 错误码处理，暂时未知有哪些错误码
		console.log(msg, code);
		throw error;
	}
	// 请求已发出，但服务器响应的状态码不在 2xx 范围内
	if (!error.responses) {
		//TODO: 错误码处理，暂时未知有哪些错误码
		console.log("Error", error.message);
	}
}

export default function request(url, params, options) {
	const _url = process.env.BASE_URL + url;
	const combineOptions = {
		method: "post", // 默认post请求
		data: params,
		headers: {
			token: "",
		},
		timeout: 10000, // 10秒超时
		withCredentials: true, //附带cookie
		...options,
	};
	axios(_url, combineOptions)
		.then(checkCode)
		.catch(disposeError);
}
